@@ -84,7 +84,7 @@ class CheckParametersConvergence(Callback):
         self.prev = current
         norm = np.linalg.norm(delta, self.ord)
         if norm < self.tolerance:
-            raise StopIteration("Convergence achieved at %d" % i)
+            raise StopIteration(f"Convergence achieved at {i}")
 
     @staticmethod
     def flatten_shared(shared_list):
