@@ -502,7 +502,7 @@ class TestSamplePPC:
             assert ppc["a"].shape == (nchains, ndraws)
 
             # test default case
-            random_state = np.random.RandomState(20160911)
+            random_state = np.random.default_rng(20160911)
             idata_ppc = pm.sample_posterior_predictive(
                 trace, var_names=["a"], random_seed=random_state
             )
@@ -628,9 +628,9 @@ class TestSamplePPC:
             assert samples["foo"].shape == (1, 40, 200)
 
     def test_model_shared_variable(self):
-        rng = np.random.RandomState(9832)
+        rng = np.random.default_rng(9832)
 
-        x = rng.randn(100)
+        x = rng.normal(size=100)
         y = x > 0
         x_shared = pytensor.shared(x)
         y_shared = pytensor.shared(y)
@@ -661,10 +661,10 @@ class TestSamplePPC:
         npt.assert_allclose(post_pred["p"], expected_p)
 
     def test_deterministic_of_observed(self):
-        rng = np.random.RandomState(8442)
+        rng = np.random.default_rng(8442)
 
-        meas_in_1 = pm.pytensorf.floatX(2 + 4 * rng.randn(10))
-        meas_in_2 = pm.pytensorf.floatX(5 + 4 * rng.randn(10))
+        meas_in_1 = pm.pytensorf.floatX(2 + 4 * rng.normal(size=10))
+        meas_in_2 = pm.pytensorf.floatX(5 + 4 * rng.normal(size=10))
         nchains = 2
         with pm.Model() as model:
             mu_in_1 = pm.Normal("mu_in_1", 0, 2)
@@ -701,10 +701,10 @@ class TestSamplePPC:
             npt.assert_allclose(ppc["in_1"] + ppc["in_2"], ppc["out"], rtol=rtol)
 
     def test_deterministic_of_observed_modified_interface(self):
-        rng = np.random.RandomState(4982)
+        rng = np.random.default_rng(4982)
 
-        meas_in_1 = pm.pytensorf.floatX(2 + 4 * rng.randn(100))
-        meas_in_2 = pm.pytensorf.floatX(5 + 4 * rng.randn(100))
+        meas_in_1 = pm.pytensorf.floatX(2 + 4 * rng.normal(size=100))
+        meas_in_2 = pm.pytensorf.floatX(5 + 4 * rng.normal(size=100))
         with pm.Model() as model:
             mu_in_1 = pm.Normal("mu_in_1", 0, 1, initval=0)
             sigma_in_1 = pm.HalfNormal("sd_in_1", 1, initval=1)
@@ -1332,10 +1332,10 @@ class TestSamplePriorPredictive:
             prior = pm.sample_prior_predictive(
                 draws=5,
                 return_inferencedata=False,
-                compile_kwargs=dict(
-                    mode=Mode("py"),
-                    updates={sharedvar: sharedvar + 1},
-                ),
+                compile_kwargs={
+                    "mode": Mode("py"),
+                    "updates": {sharedvar: sharedvar + 1},
+                },
             )
 
         assert np.all(prior["y"] == np.arange(5))
@@ -1380,10 +1380,10 @@ class TestSamplePosteriorPredictive:
                 trace=az_from_dict({"x": np.arange(5)}),
                 var_names=["y"],
                 return_inferencedata=False,
-                compile_kwargs=dict(
-                    mode=Mode("py"),
-                    updates={sharedvar: sharedvar + 1},
-                ),
+                compile_kwargs={
+                    "mode": Mode("py"),
+                    "updates": {sharedvar: sharedvar + 1},
+                },
             )
 
         assert np.all(pp["y"] == np.arange(5) * 2)
@@ -1413,7 +1413,7 @@ def test_distinct_rvs():
         Y_rv = pm.Normal("y")
 
         pp_samples = pm.sample_prior_predictive(
-            draws=2, return_inferencedata=False, random_seed=npr.RandomState(2023532)
+            draws=2, return_inferencedata=False, random_seed=npr.default_rng(2023532)
         )
 
     assert X_rv.owner.inputs[0] != Y_rv.owner.inputs[0]
@@ -1423,7 +1423,7 @@ def test_distinct_rvs():
         Y_rv = pm.Normal("y")
 
         pp_samples_2 = pm.sample_prior_predictive(
-            draws=2, return_inferencedata=False, random_seed=npr.RandomState(2023532)
+            draws=2, return_inferencedata=False, random_seed=npr.default_rng(2023532)
         )
 
     assert np.array_equal(pp_samples["y"], pp_samples_2["y"])
@@ -1467,8 +1467,8 @@ class TestNestedRandom:
     @pytest.mark.parametrize(
         ["prior_samples", "shape", "mu", "alpha"],
         [
-            [10, (3,), (None, tuple()), (None, (3,))],
-            [10, (3,), (None, (3,)), (None, tuple())],
+            [10, (3,), (None, ()), (None, (3,))],
+            [10, (3,), (None, (3,)), (None, ())],
             [
                 10,
                 (
@@ -1500,7 +1500,7 @@ class TestNestedRandom:
         prior = self.sample_prior(
             distribution=pm.NegativeBinomial,
             shape=shape,
-            nested_rvs_info=dict(mu=mu, alpha=alpha),
+            nested_rvs_info={"mu": mu, "alpha": alpha},
             prior_samples=prior_samples,
         )
         assert prior["target"].shape == (prior_samples, *shape)
@@ -1508,10 +1508,10 @@ class TestNestedRandom:
     @pytest.mark.parametrize(
         ["prior_samples", "shape", "psi", "mu", "alpha"],
         [
-            [10, (3,), (0.5, tuple()), (None, tuple()), (None, (3,))],
-            [10, (3,), (0.5, (3,)), (None, tuple()), (None, (3,))],
-            [10, (3,), (0.5, tuple()), (None, (3,)), (None, tuple())],
-            [10, (3,), (0.5, (3,)), (None, (3,)), (None, tuple())],
+            [10, (3,), (0.5, ()), (None, ()), (None, (3,))],
+            [10, (3,), (0.5, (3,)), (None, ()), (None, (3,))],
+            [10, (3,), (0.5, ()), (None, (3,)), (None, ())],
+            [10, (3,), (0.5, (3,)), (None, (3,)), (None, ())],
             [
                 10,
                 (
@@ -1546,7 +1546,7 @@ class TestNestedRandom:
         prior = self.sample_prior(
             distribution=pm.ZeroInflatedNegativeBinomial,
             shape=shape,
-            nested_rvs_info=dict(psi=psi, mu=mu, alpha=alpha),
+            nested_rvs_info={"psi": psi, "mu": mu, "alpha": alpha},
             prior_samples=prior_samples,
         )
         assert prior["target"].shape == (prior_samples, *shape)
@@ -1554,10 +1554,10 @@ class TestNestedRandom:
     @pytest.mark.parametrize(
         ["prior_samples", "shape", "nu", "sigma"],
         [
-            [10, (3,), (None, tuple()), (None, (3,))],
-            [10, (3,), (None, tuple()), (None, (3,))],
-            [10, (3,), (None, (3,)), (None, tuple())],
-            [10, (3,), (None, (3,)), (None, tuple())],
+            [10, (3,), (None, ()), (None, (3,))],
+            [10, (3,), (None, ()), (None, (3,))],
+            [10, (3,), (None, (3,)), (None, ())],
+            [10, (3,), (None, (3,)), (None, ())],
             [
                 10,
                 (
@@ -1589,7 +1589,7 @@ class TestNestedRandom:
         prior = self.sample_prior(
             distribution=pm.Rice,
             shape=shape,
-            nested_rvs_info=dict(nu=nu, sigma=sigma),
+            nested_rvs_info={"nu": nu, "sigma": sigma},
             prior_samples=prior_samples,
         )
         assert prior["target"].shape == (prior_samples, *shape)
@@ -1597,10 +1597,10 @@ class TestNestedRandom:
     @pytest.mark.parametrize(
         ["prior_samples", "shape", "mu", "sigma", "lower", "upper"],
         [
-            [10, (3,), (None, tuple()), (1.0, tuple()), (None, tuple(), -1), (None, (3,))],
-            [10, (3,), (None, tuple()), (1.0, tuple()), (None, tuple(), -1), (None, (3,))],
-            [10, (3,), (None, tuple()), (1.0, tuple()), (None, (3,), -1), (None, tuple())],
-            [10, (3,), (None, tuple()), (1.0, tuple()), (None, (3,), -1), (None, tuple())],
+            [10, (3,), (None, ()), (1.0, ()), (None, (), -1), (None, (3,))],
+            [10, (3,), (None, ()), (1.0, ()), (None, (), -1), (None, (3,))],
+            [10, (3,), (None, ()), (1.0, ()), (None, (3,), -1), (None, ())],
+            [10, (3,), (None, ()), (1.0, ()), (None, (3,), -1), (None, ())],
             [
                 10,
                 (
@@ -1608,7 +1608,7 @@ class TestNestedRandom:
                     3,
                 ),
                 (None, (3,)),
-                (1.0, tuple()),
+                (1.0, ()),
                 (None, (3,), -1),
                 (None, (3,)),
             ],
@@ -1619,21 +1619,21 @@ class TestNestedRandom:
                     3,
                 ),
                 (None, (3,)),
-                (1.0, tuple()),
+                (1.0, ()),
                 (None, (3,), -1),
                 (None, (4, 3)),
             ],
-            [10, (3,), (0.0, tuple()), (None, tuple()), (None, tuple(), -1), (None, (3,))],
-            [10, (3,), (0.0, tuple()), (None, tuple()), (None, tuple(), -1), (None, (3,))],
-            [10, (3,), (0.0, tuple()), (None, tuple()), (None, (3,), -1), (None, tuple())],
-            [10, (3,), (0.0, tuple()), (None, tuple()), (None, (3,), -1), (None, tuple())],
+            [10, (3,), (0.0, ()), (None, ()), (None, (), -1), (None, (3,))],
+            [10, (3,), (0.0, ()), (None, ()), (None, (), -1), (None, (3,))],
+            [10, (3,), (0.0, ()), (None, ()), (None, (3,), -1), (None, ())],
+            [10, (3,), (0.0, ()), (None, ()), (None, (3,), -1), (None, ())],
             [
                 10,
                 (
                     4,
                     3,
                 ),
-                (0.0, tuple()),
+                (0.0, ()),
                 (None, (3,)),
                 (None, (3,), -1),
                 (None, (3,)),
@@ -1644,7 +1644,7 @@ class TestNestedRandom:
                     4,
                     3,
                 ),
-                (0.0, tuple()),
+                (0.0, ()),
                 (None, (3,)),
                 (None, (3,), -1),
                 (None, (4, 3)),
@@ -1664,7 +1664,7 @@ class TestNestedRandom:
         prior = self.sample_prior(
             distribution=pm.TruncatedNormal,
             shape=shape,
-            nested_rvs_info=dict(mu=mu, sigma=sigma, lower=lower, upper=upper),
+            nested_rvs_info={"mu": mu, "sigma": sigma, "lower": lower, "upper": upper},
             prior_samples=prior_samples,
         )
         assert prior["target"].shape == (prior_samples, *shape)
@@ -1672,9 +1672,9 @@ class TestNestedRandom:
     @pytest.mark.parametrize(
         ["prior_samples", "shape", "c", "lower", "upper"],
         [
-            [10, (3,), (None, tuple()), (-1.0, (3,)), (2, tuple())],
-            [10, (3,), (None, tuple()), (-1.0, tuple()), (None, tuple(), 1)],
-            [10, (3,), (None, (3,)), (-1.0, tuple()), (None, tuple(), 1)],
+            [10, (3,), (None, ()), (-1.0, (3,)), (2, ())],
+            [10, (3,), (None, ()), (-1.0, ()), (None, (), 1)],
+            [10, (3,), (None, (3,)), (-1.0, ()), (None, (), 1)],
             [
                 10,
                 (
@@ -1682,7 +1682,7 @@ class TestNestedRandom:
                     3,
                 ),
                 (None, (3,)),
-                (-1.0, tuple()),
+                (-1.0, ()),
                 (None, (3,), 1),
             ],
             [
@@ -1692,7 +1692,7 @@ class TestNestedRandom:
                     3,
                 ),
                 (None, (3,)),
-                (None, tuple(), -1),
+                (None, (), -1),
                 (None, (3,), 1),
             ],
         ],
@@ -1709,7 +1709,7 @@ class TestNestedRandom:
         prior = self.sample_prior(
             distribution=pm.Triangular,
             shape=shape,
-            nested_rvs_info=dict(c=c, lower=lower, upper=upper),
+            nested_rvs_info={"c": c, "lower": lower, "upper": upper},
             prior_samples=prior_samples,
         )
         assert prior["target"].shape == (prior_samples, *shape)
