@@ -157,7 +157,7 @@ def test_explicit_sample(mp_start_method):
         10,
         step,
         chain=3,
-        seed=1,
+        rng=np.random.default_rng(1),
         mp_ctx=ctx,
         start={"a": floatX(np.array([1.0])), "b_log__": floatX(np.array(2.0))},
         step_method_pickled=step_method_pickled,
@@ -190,7 +190,7 @@ def test_iterator():
         tune=10,
         chains=3,
         cores=2,
-        seeds=[2, 3, 4],
+        rngs=np.random.default_rng(1).spawn(3),
         start_points=[start] * 3,
         step_method=step,
         progressbar=False,
