@@ -22,6 +22,8 @@ import numpy.testing as npt
 import pytensor
 import pytest
 
+from pytensor.compile.mode import Mode
+
 import pymc as pm
 
 from pymc.step_methods.metropolis import (
@@ -356,22 +358,28 @@ class TestStepMetropolis(StepMethodTester):
 
 class TestRVsAssignmentMetropolis(RVsAssignmentStepsTester):
     @pytest.mark.parametrize(
-        "step, step_kwargs",
+        "step",
         [
-            (BinaryGibbsMetropolis, {}),
-            (CategoricalGibbsMetropolis, {}),
+            BinaryMetropolis,
+            BinaryGibbsMetropolis,
+            CategoricalGibbsMetropolis,
         ],
     )
-    def test_discrete_steps(self, step, step_kwargs):
+    def test_discrete_steps(self, step):
         with pm.Model() as m:
             d1 = pm.Bernoulli("d1", p=0.5)
             d2 = pm.Bernoulli("d2", p=0.5)
 
-            with pytensor.config.change_flags(mode=fast_unstable_sampling_mode):
-                assert [m.rvs_to_values[d1]] == step([d1], **step_kwargs).vars
-            assert {m.rvs_to_values[d1], m.rvs_to_values[d2]} == set(
-                step([d1, d2], **step_kwargs).vars
-            )
+            # Test it can take initial_point, and compile_kwargs as a kwarg
+            step_kwargs = {
+                "initial_point": {
+                    "d1": np.array(0, dtype="int64"),
+                    "d2": np.array(1, dtype="int64"),
+                },
+                "compile_kwargs": {"mode": Mode(linker="py", optimizer=None)},
+            }
+            assert [m.rvs_to_values[d1]] == step([d1]).vars
+            assert {m.rvs_to_values[d1], m.rvs_to_values[d2]} == set(step([d1, d2]).vars)
 
     @pytest.mark.parametrize(
         "step, step_kwargs", [(Metropolis, {}), (DEMetropolis, {}), (DEMetropolisZ, {})]
